==> 0.7.2.tar.gz: lib/src/model/default_editors.dart <==
part of fields.model;

class BoolEditor extends FieldEditor<bool> {
  
  static final _checkBox = new String.fromCharCode(9744);
  static final _check = new String.fromCharCode(9745);
  
  var _element;
  get element => _element;
  
  BoolEditor(Field field) : super(field) {
    final desc = (field.description == null) ? '' : field.description;
    _element = toggleButton(() {
      span()
      ..text = '$_checkBox $desc'
      ..classes = ['up'];
      span()
      ..text = '$_check $desc'
      ..classes = ['down'];
    })..onToggle.listen((bool isDown) {
      if (isEnabled) {
        this.value = isDown;
      }
    });
  }
      
  void refreshElement() {
    _element
    ..disabled = !isEnabled
    ..isDown = value;
  }
}

class ColorEditor extends FieldEditor<String> {
  
  var _picker;
  var _display;
  var _element;
  get element => _element;
  
  ColorEditor(Field field) : super(field) {
    _element = span(() {
      _picker = input()
      ..type = 'color'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _picker.value;         
        this.value = _picker.value;
      });
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });
  }
  
  void refreshElement() {
    _picker
    ..disabled = !isEnabled
    ..value = value;
    _display.value = value;
  }
}

class DateTimeEditor extends FieldEditor<DateTime> {
  
  var _input;
  get element => _input;
  
  DateTimeEditor(Field field) : super(field) {
    _input = input()
    ..type = 'date' // TODO(rms): investigate 'datetime-local'
    ..onChange.listen((_) {
      this.value = _input.valueAsDate;
    });
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsDate = value;
  }
}

class DefaultEditor extends FieldEditor<String> {
  
  var _input;
  get element => _input;
    
  DefaultEditor(Field field) : super(field) {
    _input = input()
    ..type = 'text'
    ..onInput.listen((_) {
      try {
        this.value = _input.value;
        _input.classes.remove('error');
      } catch(_) {
        _input.classes.add('error');
      }
    });
  }
  
  void refreshElement() {
    _input.disabled = !isEnabled;
    if (_input.value != value) {
      _input.value = value;
    }
  }
}

class NumberEditor extends FieldEditor<num> {
  
  var _input;
  get element => _input;
  
  NumberEditor(Field field) : super(field) {
    _input = input()
    ..type = 'number'
    ..onChange.listen((_) {
      this.value = _input.valueAsNumber;
    });
    
    final match = (a) => a is Range;
    if (field.annotations.any(match)) {
      Range range = field.annotations.firstWhere(match);
      range.applyTo(_input);
    }
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsNumber = value;
  }
}

class RangeEditor extends FieldEditor<num> {
  
  var _range;
  var _display;
  var _element;
  get element => _element;
  
  RangeEditor(Field field) : super(field) {
    _element = span(() {
      _range = input()
      ..type = 'range'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _range.value; 
        this.value = _range.valueAsNumber;
      });
      
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });

    final match = (a) => a is Range;
    if (field.annotations.any(match)) {
      Range range = field.annotations.firstWhere(match);
      range.applyTo(_range);
    }
  }
  
  void refreshElement() {
    _range
    ..disabled = !isEnabled
    ..valueAsNumber = value;
    _display.value = value.toString();
  }
}

class SelectEditor extends FieldEditor<String> {
  
  var _select;
  get element => _select;
      
  SelectEditor(Field field) : super(field) {
    _select = select(() {      
      final isUseValues = (a) => a is Values;
      if (field.annotations.any(isUseValues)) {
        Values useValues = field.annotations.firstWhere(isUseValues);
        for (var v in useValues.values) {
          String valueString;
          if (field.transform != null) {
            valueString = field.transform(v);
          } else if (ValueTransform.canTransform(v.runtimeType, String)) {
            valueString = ValueTransform.transform(v, v.runtimeType, String);
          } else {
            valueString = v.toString();
          }
          option()
          ..text = valueString
          ..value = valueString;
        }
      }
    })
    ..onChange.listen((_) {
      this.value = _select.value;
    });
  }
  
  void refreshElement() {
    _select
    ..disabled = !isEnabled
    ..value = value;
  }
}

==> 0.8.4.tar.gz: lib/src/model/default_editors.dart <==
part of fields.model;

class BoolEditor extends FieldEditor<bool> {
  
  static final _checkBox = new String.fromCharCode(9744);
  static final _check = new String.fromCharCode(9745);
  
  var _element;
  get element => _element;
  
  BoolEditor(Field field) : super(field) {
    final desc = (field.description == null) ? '' : field.description;
    _element = toggleButton(() {
      span()
      ..text = '$_checkBox $desc'
      ..classes = ['up'];
      span()
      ..text = '$_check $desc'
      ..classes = ['down'];
    })..onToggle.listen((bool isDown) {
      if (isEnabled) {
        this.value = isDown;
      }
    });
  }
      
  void refreshElement() {
    _element
    ..disabled = !isEnabled
    ..isDown = value;
  }
}

class ColorEditor extends FieldEditor<String> {
  
  var _picker;
  var _display;
  var _element;
  get element => _element;
  
  ColorEditor(Field field) : super(field) {
    _element = span(() {
      _picker = input()
      ..type = 'color'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _picker.value;         
        this.value = _picker.value;
      });
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });
  }
  
  void refreshElement() {
    _picker
    ..disabled = !isEnabled
    ..value = value;
    _display.value = value;
  }
}

class DateTimeEditor extends FieldEditor<DateTime> {
  
  var _input;
  get element => _input;
  
  DateTimeEditor(Field field) : super(field) {
    _input = input()
    ..type = 'date' // TODO: investigate 'datetime-local'
    ..onChange.listen((_) {
      this.value = _input.valueAsDate;
    });
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsDate = value;
  }
}

class DefaultEditor extends FieldEditor<String> {
  
  var _input;
  get element => _input;
    
  DefaultEditor(Field field) : super(field) {
    _input = input()
    ..type = 'text'
    ..onInput.listen((_) {
      try {
        this.value = _input.value;
        _input.classes.remove('error');
      } catch(_) {
        _input.classes.add('error');
      }
    });
  }
  
  void refreshElement() {
    _input.disabled = !isEnabled;
    if (_input.value != value) {
      _input.value = value;
    }
  }
}

class NumberEditor extends FieldEditor<num> {
  
  var _input;
  get element => _input;
  
  NumberEditor(Field field) : super(field) {
    _input = input()
    ..type = 'number'
    ..onChange.listen((_) {
      this.value = _input.valueAsNumber;
    });
    
    final match = (a) => a is Range;
    if (field.annotations.any(match)) {
      Range range = field.annotations.firstWhere(match);
      range.applyTo(_input);
    }
  }
  
  void refreshElement() {
    _input
    ..disabled = !isEnabled
    ..valueAsNumber = value;
  }
}

class RangeEditor extends FieldEditor<num> {
  
  var _range;
  var _display;
  var _element;
  get element => _element;
  
  RangeEditor(Field field) : super(field) {
    _element = span(() {
      _range = input()
      ..type = 'range'
      ..style.float = 'left'
      ..onChange.listen((_) {
        _display.value = _range.value; 
        this.value = _range.valueAsNumber;
      });
      
      div(() {
        _display = input()
        ..type = 'text'
        ..disabled = true;
      })
      ..style.overflow = 'hidden';
    });

    final match = (a) => a is Range;
    if (field.annotations.any(match)) {
      Range range = field.annotations.firstWhere(match);
      range.applyTo(_range);
    }
  }
  
  void refreshElement() {
    _range
    ..disabled = !isEnabled
    ..valueAsNumber = value;
    _display.value = value.toString();
  }
}

class SelectEditor extends FieldEditor<String> {
  
  var _select;
  get element => _select;
      
  SelectEditor(Field field) : super(field) {
    _select = select(() {      
      final isUseValues = (a) => a is Values;
      if (field.annotations.any(isUseValues)) {
        Values useValues = field.annotations.firstWhere(isUseValues);
        for (var v in useValues.values) {
          String valueString;
          if (field.transform != null) {
            valueString = field.transform(v);
          } else if (ValueTransform.canTransform(v.runtimeType, String)) {
            valueString = ValueTransform.transform(v, v.runtimeType, String);
          } else {
            valueString = v.toString();
          }
          option()
          ..text = valueString
          ..value = valueString;
        }
      }
    })
    ..onChange.listen((_) {
      this.value = _select.value;
    });
  }
  
  void refreshElement() {
    _select
    ..disabled = !isEnabled
    ..value = value;
  }
}
